"""
Type annotations for mgn service client.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html)

Usage::

    ```python
    import boto3
    from mypy_boto3_mgn import mgnClient

    client: mgnClient = boto3.client("mgn")
    ```
"""
import sys
from typing import Any, Dict, List, Type, overload

from botocore.client import ClientMeta

from mypy_boto3_mgn.literals import (
    LaunchDisposition,
    ReplicationConfigurationDataPlaneRouting,
    ReplicationConfigurationDefaultLargeStagingDiskType,
    ReplicationConfigurationEbsEncryption,
    TargetInstanceTypeRightSizingMethod,
)
from mypy_boto3_mgn.paginator import (
    DescribeJobLogItemsPaginator,
    DescribeJobsPaginator,
    DescribeReplicationConfigurationTemplatesPaginator,
    DescribeSourceServersPaginator,
)
from mypy_boto3_mgn.type_defs import (
    ChangeServerLifeCycleStateSourceServerLifecycleTypeDef,
    DescribeJobLogItemsResponseTypeDef,
    DescribeJobsRequestFiltersTypeDef,
    DescribeJobsResponseTypeDef,
    DescribeReplicationConfigurationTemplatesResponseTypeDef,
    DescribeSourceServersRequestFiltersTypeDef,
    DescribeSourceServersResponseTypeDef,
    LaunchConfigurationTypeDef,
    LicensingTypeDef,
    ListTagsForResourceResponseTypeDef,
    ReplicationConfigurationReplicatedDiskTypeDef,
    ReplicationConfigurationTemplateTypeDef,
    ReplicationConfigurationTypeDef,
    SourceServerTypeDef,
    StartCutoverResponseTypeDef,
    StartTestResponseTypeDef,
    TerminateTargetInstancesResponseTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = ("mgnClient",)

class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str
    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str

class Exceptions:
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    UninitializedAccountException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]

class mgnClient:
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client)
    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html)
    """

    meta: ClientMeta
    exceptions: Exceptions
    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.can_paginate)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#can-paginate)
        """
    def change_server_life_cycle_state(
        self, lifeCycle: ChangeServerLifeCycleStateSourceServerLifecycleTypeDef, sourceServerID: str
    ) -> "SourceServerTypeDef":
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.change_server_life_cycle_state)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#change-server-life-cycle-state)
        """
    def create_replication_configuration_template(
        self,
        associateDefaultSecurityGroup: bool,
        bandwidthThrottling: int,
        createPublicIP: bool,
        dataPlaneRouting: ReplicationConfigurationDataPlaneRouting,
        defaultLargeStagingDiskType: ReplicationConfigurationDefaultLargeStagingDiskType,
        ebsEncryption: ReplicationConfigurationEbsEncryption,
        replicationServerInstanceType: str,
        replicationServersSecurityGroupsIDs: List[str],
        stagingAreaSubnetId: str,
        stagingAreaTags: Dict[str, str],
        useDedicatedReplicationServer: bool,
        ebsEncryptionKeyArn: str = None,
        tags: Dict[str, str] = None,
    ) -> "ReplicationConfigurationTemplateTypeDef":
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.create_replication_configuration_template)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#create-replication-configuration-template)
        """
    def delete_job(self, jobID: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.delete_job)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#delete-job)
        """
    def delete_replication_configuration_template(
        self, replicationConfigurationTemplateID: str
    ) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.delete_replication_configuration_template)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#delete-replication-configuration-template)
        """
    def delete_source_server(self, sourceServerID: str) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.delete_source_server)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#delete-source-server)
        """
    def describe_job_log_items(
        self, jobID: str, maxResults: int = None, nextToken: str = None
    ) -> DescribeJobLogItemsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.describe_job_log_items)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe-job-log-items)
        """
    def describe_jobs(
        self,
        filters: DescribeJobsRequestFiltersTypeDef,
        maxResults: int = None,
        nextToken: str = None,
    ) -> DescribeJobsResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.describe_jobs)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe-jobs)
        """
    def describe_replication_configuration_templates(
        self,
        replicationConfigurationTemplateIDs: List[str],
        maxResults: int = None,
        nextToken: str = None,
    ) -> DescribeReplicationConfigurationTemplatesResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.describe_replication_configuration_templates)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe-replication-configuration-templates)
        """
    def describe_source_servers(
        self,
        filters: DescribeSourceServersRequestFiltersTypeDef,
        maxResults: int = None,
        nextToken: str = None,
    ) -> DescribeSourceServersResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.describe_source_servers)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe-source-servers)
        """
    def disconnect_from_service(self, sourceServerID: str) -> "SourceServerTypeDef":
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.disconnect_from_service)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#disconnect-from-service)
        """
    def finalize_cutover(self, sourceServerID: str) -> "SourceServerTypeDef":
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.finalize_cutover)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#finalize-cutover)
        """
    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.generate_presigned_url)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#generate-presigned-url)
        """
    def get_launch_configuration(self, sourceServerID: str) -> LaunchConfigurationTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.get_launch_configuration)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get-launch-configuration)
        """
    def get_replication_configuration(self, sourceServerID: str) -> ReplicationConfigurationTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.get_replication_configuration)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get-replication-configuration)
        """
    def initialize_service(self) -> Dict[str, Any]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.initialize_service)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#initialize-service)
        """
    def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.list_tags_for_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#list-tags-for-resource)
        """
    def mark_as_archived(self, sourceServerID: str) -> "SourceServerTypeDef":
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.mark_as_archived)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#mark-as-archived)
        """
    def retry_data_replication(self, sourceServerID: str) -> "SourceServerTypeDef":
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.retry_data_replication)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#retry-data-replication)
        """
    def start_cutover(
        self, sourceServerIDs: List[str], tags: Dict[str, str] = None
    ) -> StartCutoverResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.start_cutover)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#start-cutover)
        """
    def start_test(
        self, sourceServerIDs: List[str], tags: Dict[str, str] = None
    ) -> StartTestResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.start_test)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#start-test)
        """
    def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.tag_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#tag-resource)
        """
    def terminate_target_instances(
        self, sourceServerIDs: List[str], tags: Dict[str, str] = None
    ) -> TerminateTargetInstancesResponseTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.terminate_target_instances)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#terminate-target-instances)
        """
    def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.untag_resource)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#untag-resource)
        """
    def update_launch_configuration(
        self,
        sourceServerID: str,
        copyPrivateIp: bool = None,
        copyTags: bool = None,
        launchDisposition: LaunchDisposition = None,
        licensing: "LicensingTypeDef" = None,
        name: str = None,
        targetInstanceTypeRightSizingMethod: TargetInstanceTypeRightSizingMethod = None,
    ) -> LaunchConfigurationTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.update_launch_configuration)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#update-launch-configuration)
        """
    def update_replication_configuration(
        self,
        sourceServerID: str,
        associateDefaultSecurityGroup: bool = None,
        bandwidthThrottling: int = None,
        createPublicIP: bool = None,
        dataPlaneRouting: ReplicationConfigurationDataPlaneRouting = None,
        defaultLargeStagingDiskType: ReplicationConfigurationDefaultLargeStagingDiskType = None,
        ebsEncryption: ReplicationConfigurationEbsEncryption = None,
        ebsEncryptionKeyArn: str = None,
        name: str = None,
        replicatedDisks: List["ReplicationConfigurationReplicatedDiskTypeDef"] = None,
        replicationServerInstanceType: str = None,
        replicationServersSecurityGroupsIDs: List[str] = None,
        stagingAreaSubnetId: str = None,
        stagingAreaTags: Dict[str, str] = None,
        useDedicatedReplicationServer: bool = None,
    ) -> ReplicationConfigurationTypeDef:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.update_replication_configuration)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#update-replication-configuration)
        """
    def update_replication_configuration_template(
        self,
        replicationConfigurationTemplateID: str,
        arn: str = None,
        associateDefaultSecurityGroup: bool = None,
        bandwidthThrottling: int = None,
        createPublicIP: bool = None,
        dataPlaneRouting: ReplicationConfigurationDataPlaneRouting = None,
        defaultLargeStagingDiskType: ReplicationConfigurationDefaultLargeStagingDiskType = None,
        ebsEncryption: ReplicationConfigurationEbsEncryption = None,
        ebsEncryptionKeyArn: str = None,
        replicationServerInstanceType: str = None,
        replicationServersSecurityGroupsIDs: List[str] = None,
        stagingAreaSubnetId: str = None,
        stagingAreaTags: Dict[str, str] = None,
        useDedicatedReplicationServer: bool = None,
    ) -> "ReplicationConfigurationTemplateTypeDef":
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Client.update_replication_configuration_template)
        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#update-replication-configuration-template)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["describe_job_log_items"]
    ) -> DescribeJobLogItemsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Paginator.DescribeJobLogItems)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describejoblogitemspaginator)
        """
    @overload
    def get_paginator(self, operation_name: Literal["describe_jobs"]) -> DescribeJobsPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Paginator.DescribeJobs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describejobspaginator)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["describe_replication_configuration_templates"]
    ) -> DescribeReplicationConfigurationTemplatesPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Paginator.DescribeReplicationConfigurationTemplates)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describereplicationconfigurationtemplatespaginator)
        """
    @overload
    def get_paginator(
        self, operation_name: Literal["describe_source_servers"]
    ) -> DescribeSourceServersPaginator:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/mgn.html#mgn.Paginator.DescribeSourceServers)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describesourceserverspaginator)
        """



"""
Type annotations for mgn service type definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/type_defs.html)

Usage::

    ```python
    from mypy_boto3_mgn.type_defs import CPUTypeDef

    data: CPUTypeDef = {...}
    ```
"""
import sys
from typing import Dict, List

from mypy_boto3_mgn.literals import (
    ChangeServerLifeCycleStateSourceServerLifecycleState,
    DataReplicationErrorString,
    DataReplicationInitiationStepName,
    DataReplicationInitiationStepStatus,
    DataReplicationState,
    FirstBoot,
    InitiatedBy,
    JobLogEvent,
    JobStatus,
    JobType,
    LaunchDisposition,
    LaunchStatus,
    LifeCycleState,
    ReplicationConfigurationDataPlaneRouting,
    ReplicationConfigurationDefaultLargeStagingDiskType,
    ReplicationConfigurationEbsEncryption,
    ReplicationConfigurationReplicatedDiskStagingDiskType,
    TargetInstanceTypeRightSizingMethod,
)

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict

__all__ = (
    "CPUTypeDef",
    "ChangeServerLifeCycleStateSourceServerLifecycleTypeDef",
    "DataReplicationErrorTypeDef",
    "DataReplicationInfoReplicatedDiskTypeDef",
    "DataReplicationInfoTypeDef",
    "DataReplicationInitiationStepTypeDef",
    "DataReplicationInitiationTypeDef",
    "DescribeJobLogItemsResponseTypeDef",
    "DescribeJobsRequestFiltersTypeDef",
    "DescribeJobsResponseTypeDef",
    "DescribeReplicationConfigurationTemplatesResponseTypeDef",
    "DescribeSourceServersRequestFiltersTypeDef",
    "DescribeSourceServersResponseTypeDef",
    "DiskTypeDef",
    "IdentificationHintsTypeDef",
    "JobLogEventDataTypeDef",
    "JobLogTypeDef",
    "JobTypeDef",
    "LaunchConfigurationTypeDef",
    "LaunchedInstanceTypeDef",
    "LicensingTypeDef",
    "LifeCycleLastCutoverFinalizedTypeDef",
    "LifeCycleLastCutoverInitiatedTypeDef",
    "LifeCycleLastCutoverRevertedTypeDef",
    "LifeCycleLastCutoverTypeDef",
    "LifeCycleLastTestFinalizedTypeDef",
    "LifeCycleLastTestInitiatedTypeDef",
    "LifeCycleLastTestRevertedTypeDef",
    "LifeCycleLastTestTypeDef",
    "LifeCycleTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "NetworkInterfaceTypeDef",
    "OSTypeDef",
    "PaginatorConfigTypeDef",
    "ParticipatingServerTypeDef",
    "ReplicationConfigurationReplicatedDiskTypeDef",
    "ReplicationConfigurationTemplateTypeDef",
    "ReplicationConfigurationTypeDef",
    "SourcePropertiesTypeDef",
    "SourceServerTypeDef",
    "StartCutoverResponseTypeDef",
    "StartTestResponseTypeDef",
    "TerminateTargetInstancesResponseTypeDef",
)

class CPUTypeDef(TypedDict, total=False):
    cores: int
    modelName: str

class ChangeServerLifeCycleStateSourceServerLifecycleTypeDef(TypedDict):
    state: ChangeServerLifeCycleStateSourceServerLifecycleState

class DataReplicationErrorTypeDef(TypedDict, total=False):
    error: DataReplicationErrorString
    rawError: str

class DataReplicationInfoReplicatedDiskTypeDef(TypedDict, total=False):
    backloggedStorageBytes: int
    deviceName: str
    replicatedStorageBytes: int
    rescannedStorageBytes: int
    totalStorageBytes: int

class DataReplicationInfoTypeDef(TypedDict, total=False):
    dataReplicationError: "DataReplicationErrorTypeDef"
    dataReplicationInitiation: "DataReplicationInitiationTypeDef"
    dataReplicationState: DataReplicationState
    etaDateTime: str
    lagDuration: str
    replicatedDisks: List["DataReplicationInfoReplicatedDiskTypeDef"]

class DataReplicationInitiationStepTypeDef(TypedDict, total=False):
    name: DataReplicationInitiationStepName
    status: DataReplicationInitiationStepStatus

class DataReplicationInitiationTypeDef(TypedDict, total=False):
    nextAttemptDateTime: str
    startDateTime: str
    steps: List["DataReplicationInitiationStepTypeDef"]

class DescribeJobLogItemsResponseTypeDef(TypedDict, total=False):
    items: List["JobLogTypeDef"]
    nextToken: str

class DescribeJobsRequestFiltersTypeDef(TypedDict, total=False):
    fromDate: str
    jobIDs: List[str]
    toDate: str

class DescribeJobsResponseTypeDef(TypedDict, total=False):
    items: List["JobTypeDef"]
    nextToken: str

class DescribeReplicationConfigurationTemplatesResponseTypeDef(TypedDict, total=False):
    items: List["ReplicationConfigurationTemplateTypeDef"]
    nextToken: str

class DescribeSourceServersRequestFiltersTypeDef(TypedDict, total=False):
    isArchived: bool
    sourceServerIDs: List[str]

class DescribeSourceServersResponseTypeDef(TypedDict, total=False):
    items: List["SourceServerTypeDef"]
    nextToken: str

DiskTypeDef = TypedDict("DiskTypeDef", {"bytes": int, "deviceName": str}, total=False)

class IdentificationHintsTypeDef(TypedDict, total=False):
    awsInstanceID: str
    fqdn: str
    hostname: str
    vmWareUuid: str

class JobLogEventDataTypeDef(TypedDict, total=False):
    conversionServerID: str
    rawError: str
    sourceServerID: str
    targetInstanceID: str

class JobLogTypeDef(TypedDict, total=False):
    event: JobLogEvent
    eventData: "JobLogEventDataTypeDef"
    logDateTime: str

_RequiredJobTypeDef = TypedDict("_RequiredJobTypeDef", {"jobID": str})
_OptionalJobTypeDef = TypedDict(
    "_OptionalJobTypeDef",
    {
        "arn": str,
        "creationDateTime": str,
        "endDateTime": str,
        "initiatedBy": InitiatedBy,
        "participatingServers": List["ParticipatingServerTypeDef"],
        "status": JobStatus,
        "tags": Dict[str, str],
        "type": JobType,
    },
    total=False,
)

class JobTypeDef(_RequiredJobTypeDef, _OptionalJobTypeDef):
    pass

class LaunchConfigurationTypeDef(TypedDict, total=False):
    copyPrivateIp: bool
    copyTags: bool
    ec2LaunchTemplateID: str
    launchDisposition: LaunchDisposition
    licensing: "LicensingTypeDef"
    name: str
    sourceServerID: str
    targetInstanceTypeRightSizingMethod: TargetInstanceTypeRightSizingMethod

class LaunchedInstanceTypeDef(TypedDict, total=False):
    ec2InstanceID: str
    firstBoot: FirstBoot
    jobID: str

class LicensingTypeDef(TypedDict, total=False):
    osByol: bool

class LifeCycleLastCutoverFinalizedTypeDef(TypedDict, total=False):
    apiCallDateTime: str

class LifeCycleLastCutoverInitiatedTypeDef(TypedDict, total=False):
    apiCallDateTime: str
    jobID: str

class LifeCycleLastCutoverRevertedTypeDef(TypedDict, total=False):
    apiCallDateTime: str

class LifeCycleLastCutoverTypeDef(TypedDict, total=False):
    finalized: "LifeCycleLastCutoverFinalizedTypeDef"
    initiated: "LifeCycleLastCutoverInitiatedTypeDef"
    reverted: "LifeCycleLastCutoverRevertedTypeDef"

class LifeCycleLastTestFinalizedTypeDef(TypedDict, total=False):
    apiCallDateTime: str

class LifeCycleLastTestInitiatedTypeDef(TypedDict, total=False):
    apiCallDateTime: str
    jobID: str

class LifeCycleLastTestRevertedTypeDef(TypedDict, total=False):
    apiCallDateTime: str

class LifeCycleLastTestTypeDef(TypedDict, total=False):
    finalized: "LifeCycleLastTestFinalizedTypeDef"
    initiated: "LifeCycleLastTestInitiatedTypeDef"
    reverted: "LifeCycleLastTestRevertedTypeDef"

class LifeCycleTypeDef(TypedDict, total=False):
    addedToServiceDateTime: str
    elapsedReplicationDuration: str
    firstByteDateTime: str
    lastCutover: "LifeCycleLastCutoverTypeDef"
    lastSeenByServiceDateTime: str
    lastTest: "LifeCycleLastTestTypeDef"
    state: LifeCycleState

class ListTagsForResourceResponseTypeDef(TypedDict, total=False):
    tags: Dict[str, str]

class NetworkInterfaceTypeDef(TypedDict, total=False):
    ips: List[str]
    isPrimary: bool
    macAddress: str

class OSTypeDef(TypedDict, total=False):
    fullString: str

class PaginatorConfigTypeDef(TypedDict, total=False):
    MaxItems: int
    PageSize: int
    StartingToken: str

class ParticipatingServerTypeDef(TypedDict, total=False):
    launchStatus: LaunchStatus
    sourceServerID: str

class ReplicationConfigurationReplicatedDiskTypeDef(TypedDict, total=False):
    deviceName: str
    iops: int
    isBootDisk: bool
    stagingDiskType: ReplicationConfigurationReplicatedDiskStagingDiskType

class _RequiredReplicationConfigurationTemplateTypeDef(TypedDict):
    replicationConfigurationTemplateID: str

class ReplicationConfigurationTemplateTypeDef(
    _RequiredReplicationConfigurationTemplateTypeDef, total=False
):
    arn: str
    associateDefaultSecurityGroup: bool
    bandwidthThrottling: int
    createPublicIP: bool
    dataPlaneRouting: ReplicationConfigurationDataPlaneRouting
    defaultLargeStagingDiskType: ReplicationConfigurationDefaultLargeStagingDiskType
    ebsEncryption: ReplicationConfigurationEbsEncryption
    ebsEncryptionKeyArn: str
    replicationServerInstanceType: str
    replicationServersSecurityGroupsIDs: List[str]
    stagingAreaSubnetId: str
    stagingAreaTags: Dict[str, str]
    tags: Dict[str, str]
    useDedicatedReplicationServer: bool

class ReplicationConfigurationTypeDef(TypedDict, total=False):
    associateDefaultSecurityGroup: bool
    bandwidthThrottling: int
    createPublicIP: bool
    dataPlaneRouting: ReplicationConfigurationDataPlaneRouting
    defaultLargeStagingDiskType: ReplicationConfigurationDefaultLargeStagingDiskType
    ebsEncryption: ReplicationConfigurationEbsEncryption
    ebsEncryptionKeyArn: str
    name: str
    replicatedDisks: List["ReplicationConfigurationReplicatedDiskTypeDef"]
    replicationServerInstanceType: str
    replicationServersSecurityGroupsIDs: List[str]
    sourceServerID: str
    stagingAreaSubnetId: str
    stagingAreaTags: Dict[str, str]
    useDedicatedReplicationServer: bool

class SourcePropertiesTypeDef(TypedDict, total=False):
    cpus: List["CPUTypeDef"]
    disks: List["DiskTypeDef"]
    identificationHints: "IdentificationHintsTypeDef"
    lastUpdatedDateTime: str
    networkInterfaces: List["NetworkInterfaceTypeDef"]
    os: "OSTypeDef"
    ramBytes: int
    recommendedInstanceType: str

class SourceServerTypeDef(TypedDict, total=False):
    arn: str
    dataReplicationInfo: "DataReplicationInfoTypeDef"
    isArchived: bool
    launchedInstance: "LaunchedInstanceTypeDef"
    lifeCycle: "LifeCycleTypeDef"
    sourceProperties: "SourcePropertiesTypeDef"
    sourceServerID: str
    tags: Dict[str, str]

class StartCutoverResponseTypeDef(TypedDict, total=False):
    job: "JobTypeDef"

class StartTestResponseTypeDef(TypedDict, total=False):
    job: "JobTypeDef"

class TerminateTargetInstancesResponseTypeDef(TypedDict, total=False):
    job: "JobTypeDef"
